import json

from django.conf import settings
from django.http import HttpResponse


class JsonResponse(HttpResponse):
    """
    Returns a HTTP response with JSON content type. Performs automatic
    serialization if given an object.
    """

    def __init__(self, obj=None, **kwargs):

        # Perform JSON serialization
        if obj:
            # Pretty print in debug mode
            indent_level = 4 if settings.DEBUG else 0
            content = json.dumps(obj, indent=indent_level)
        else:
            content = ''

        # Content type and status code for the response
        content_type = 'application/json; charset=%s' % settings.DEFAULT_CHARSET
        status_code = kwargs.get('status', 200)

        # Return response as JSON
        super(JsonResponse, self).__init__(
            content,
            content_type=content_type,
            status=status_code
        )



from django.contrib.auth.decorators import login_required
from django.views.generic import TemplateView
from django.utils.decorators import method_decorator


class LimitedTemplateView(TemplateView):
    """
    Wrapper around TemplateView generic view with a login required decorator.

    Example usage in URL config:
        url(r'^secret/$', LimitedTemplateView.as_view(template_name='secret.html'), name='secret'),
    """

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(LimitedTemplateView, self).dispatch(*args, **kwargs)
